@@ -11,8 +11,8 @@ rctp<-function(n, a, b, gamma){
   if ( mode(c(n,a,b,gamma)) != "numeric")
     stop( "non-numeric argument to mathematical function")
 
-  if( gamma <= 2 * a )
-    stop("gamma must be greater than 2a")
+  if( (gamma <= 2 * a) || (gamma <= 0) )
+    stop("gamma must be greater than max(0,2a)")
 
   icomplex <- sqrt(as.complex(-1))
 
